#!/usr/bin/env node
"use strict";

const twitterBot = require("../lib/instance");

const startScraper = async (argv) => {
    try{
        argv.cli = true;
        argv.username = argv['login-username'];
        argv.password = argv['login-password']

        let result = await twitterBot(argv)._input({
            type: 'scrape',
            action: argv._[0],
            input: argv.id,
            number: argv.number,
        });

        if (result.json){
            console.log(`JSON file saved: ${process.cwd()}/${result.json}`);
        }
        if (result.csv){
            console.log(`CSV file saved: ${process.cwd()}/${result.csv}`);
        }
        if (result.message){
            console.log(result.message);
        }
    } catch(error){
        console.log(error);
    }
}

require("yargs")
    .usage('Usage: $0 <command> [options]')
    .example(`twitter-buddy followers TWITTER_USERNAME -u TWITTER_USERNAME -p TWITTER_PASSWORD -n 100`)
    .example(`twitter-buddy retweetedBy TWEET_ID -u TWITTER_USERNAME -p TWITTER_PASSWORD -n 100`)
    .command(
        "retweetedBy [id]", 
        "users who retweeted specific tweet", 
        {}, 
        (argv) => {
            startScraper(argv);
        }
    )
    .command(
        "likedBy [id]", 
        "users who liked specific tweet", 
        {}, 
        (argv) => {
            startScraper(argv);
        }
    )
    .command(
        "conversation [id]", 
        "tweet comments", 
        {}, 
        (argv) => {
            startScraper(argv);
        }
    )
    .command(
        "followers [id]", 
        "user followers", 
        {}, 
        (argv) => {
            startScraper(argv);
        }
    )
    .command(
        "tweets [id]", 
        "user tweets", 
        {}, 
        (argv) => {
            startScraper(argv);
        }
    )
    .command(
        "favorites [id]", 
        "user favorites/likes", 
        {}, 
        (argv) => {
            startScraper(argv);
        }
    )
    .options({
        'help': {
            alias: 'h',
            describe: 'help'
        },
        'login-username': {
            alias: 'u',
            default: '',
            type: 'string',
            describe: "Your twitter username"
        },
        'login-password': {
            alias: 'p',
            default: '',
            type: 'string',
            describe: "Your twitter password"
        },
        'number':{
            alias: 'n',
            default: 20,
            type: 'integer',
            describe: 'Number of inputs to scrape'
        },
        'csv':{
            default: true,
            type: 'boolean',
            describe: 'Save to a CSV file?'
        },
        'json':{
            default: false,
            type: 'boolean',
            describe: 'Save to a JSON file?'
        },
        'timeout':{
            default: 0,
            type: 'integer',
            describe: 'If the "rate limit" error received or emtpy result then you can try to set {timeout}. Timeout is in milliseconds: 1000 = 1 second'
        },
    })
    .demandCommand()
    .argv